@@ -487,6 +487,7 @@ class MatriceDeployClient:
         input: Union[str, int],
         fps: int = 10,
         stream_key: Optional[str] = None,
+        stream_group_key: Optional[str] = None,
         quality: int = 95,
         width: Optional[int] = None,
         height: Optional[int] = None,
@@ -512,6 +513,7 @@ class MatriceDeployClient:
             input=input,
             fps=fps,
             stream_key=stream_key,
+            stream_group_key=stream_group_key,
             quality=quality,
             width=width,
             height=height,
@@ -522,6 +524,7 @@ class MatriceDeployClient:
         input: Union[str, int],
         fps: int = 10,
         stream_key: Optional[str] = None,
+        stream_group_key: Optional[str] = None,
         quality: int = 95,
         width: Optional[int] = None,
         height: Optional[int] = None,
@@ -547,6 +550,7 @@ class MatriceDeployClient:
             input=input,
             fps=fps,
             stream_key=stream_key,
+            stream_group_key=stream_group_key,
             quality=quality,
             width=width,
             height=height,
