@@ -119,6 +119,7 @@ from .usecases.leaf import LeafConfig, LeafUseCase
 from .usecases.blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
 from .usecases.skin_cancer_classification_img import SkinCancerClassificationConfig, SkinCancerClassificationUseCase
 from .usecases.plaque_segmentation_img import PlaqueSegmentationConfig, PlaqueSegmentationUseCase
+from .usecases.smoker_detection import SmokerDetectionUseCase, SmokerDetectionConfig
 
 # Use case implementations
 from .usecases import (
@@ -170,6 +171,7 @@ from .usecases import (
     WindmillMaintenanceUseCase,
     CarPartSegmentationUseCase,
     FlowerUseCase,
+    SmokerDetectionUseCase,
 
     #Put all IMAGE based usecases here
     BloodCancerDetectionUseCase,
@@ -233,6 +235,7 @@ _wound_segmentation = WoundSegmentationUseCase()
 _leaf_disease = LeafDiseaseDetectionUseCase()
 _flower_segmentation = FlowerUseCase()
 _leaf_det = LeafUseCase()
+_smoker_detection = SmokerDetectionUseCase()
 
 #Put all IMAGE based usecases here
 _blood_cancer_detection = BloodCancerDetectionUseCase()
@@ -297,6 +300,7 @@ registry.register_use_case(_leaf_disease.category, _leaf_disease.name, LeafDisea
 registry.register_use_case(_flower_segmentation.category, _flower_segmentation.name, FlowerUseCase)
 registry.register_use_case(_parking_det.category, _parking_det.name, ParkingUseCase)
 registry.register_use_case(_leaf_det.category, _leaf_det.name, LeafUseCase)
+registry.register_use_case(_smoker_detection.category, _smoker_detection.name, SmokerDetectionUseCase)
 
 #Put all IMAGE based usecases here
 registry.register_use_case(_blood_cancer_detection.category, _blood_cancer_detection.name, BloodCancerDetectionUseCase)
@@ -483,6 +487,7 @@ __all__ = [
     'LaneDetectionConfig',
     'WindmillMaintenanceConfig',
     'FlowerConfig',
+    'SmokerDetectionConfig',
 
     #Put all IMAGE based usecase CONFIGS here
     'BloodCancerDetectionConfig',
@@ -540,6 +545,7 @@ __all__ = [
     'LaneDetectionUseCase',
     'WindmillMaintenanceUseCase',
     'FlowerUseCase',
+    'SmokerDetectionUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
