@@ -9,6 +9,7 @@ from typing import Any, Dict, List, Optional
 from dataclasses import dataclass, field
 import time
 import re
+from collections import Counter
 
 from ..core.base import (
     BaseProcessor,
@@ -40,10 +41,10 @@ class FireSmokeConfig(BaseConfig):
 
     # Only fire and smoke categories included here (exclude normal)
     fire_smoke_categories: List[str] = field(
-        default_factory=lambda: ["Fire", "Smoke"]
+        default_factory=lambda: ["fire", "smoke"]
     )
     target_categories: List[str] = field(
-        default_factory=lambda: ['Fire']
+        default_factory=lambda: ['fire']
     )
 
     alert_config: Optional[AlertConfig] = None
@@ -54,8 +55,8 @@ class FireSmokeConfig(BaseConfig):
     # Map only fire and smoke; ignore normal (index 1 not included)
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-            0: "Fire",
-            1: "Smoke",
+            0: "fire",
+            1: "smoke",
         }
     )
 
@@ -65,7 +66,7 @@ class FireSmokeConfig(BaseConfig):
     smoothing_window_size: int = 5
     smoothing_cooldown_frames: int = 10
     smoothing_confidence_range_factor: float = 0.2
-    threshold_area: Optional[float] = 307200.0
+    threshold_area: Optional[float] = 250200.0
 
     def __post_init__(self):
         if not (0.0 <= self.confidence_threshold <= 1.0):
@@ -92,10 +93,11 @@ class FireSmokeUseCase(BaseProcessor):
 
         self.smoothing_tracker = None  # Required for bbox smoothing
         self._fire_smoke_recent_history = []
-        self.target_categories=['Fire']
+        self.target_categories=['fire']
 
-        self._ascending_alert_list: List[int] = []
+        self._ascending_alert_list: List[str] = []
         self.current_incident_end_timestamp: str = "N/A"
+        #self.fire_smoke_stack:List[int] = []
 
     def process(
             self,
@@ -139,7 +141,7 @@ class FireSmokeUseCase(BaseProcessor):
                 self.logger.debug("Applied category mapping")
 
             if self.target_categories:
-                processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
+                processed_data = [d for d in processed_data if d.get('category').lower() in self.target_categories]
                 self.logger.debug(f"Applied category filtering")
 
             # Step 3.5: BBox smoothing for fire/smoke
@@ -187,6 +189,8 @@ class FireSmokeUseCase(BaseProcessor):
                     frame_number = start_frame
 
              # Step 7: alerts
+            print("-----------ALERT_PROCESSING_IPP-----------")
+            print(fire_smoke_summary)
             alerts = self._check_alerts(fire_smoke_summary, frame_number, config, stream_info)
 
 
@@ -243,24 +247,24 @@ class FireSmokeUseCase(BaseProcessor):
             self, summary: Dict, frame_number:Any, config: FireSmokeConfig, stream_info: Optional[Dict[str, Any]] = None
     ) -> List[Dict]:
         """Raise alerts if fire or smoke detected with severity based on intensity."""
-        def get_trend(data, lookback=900, threshold=0.6):
+        def get_trend(data, lookback=23, prior=14):
             '''
             Determine if the trend is ascending or descending based on actual value progression.
-            Now works with values 0,1,2,3 (not just binary).
+            Now works with determining dominant levels.
             '''
-            window = data[-lookback:] if len(data) >= lookback else data
-            if len(window) < 2:
-                return True  # not enough data to determine trend
-            increasing = 0
-            total = 0
-            for i in range(1, len(window)):
-                if window[i] >= window[i - 1]:
-                    increasing += 1
-                total += 1
-            ratio = increasing / total
-            if ratio >= threshold:
+            if len(data) < lookback:
                 return True
-            elif ratio <= (1 - threshold):
+            post=lookback-prior-1
+            levels_list = ["low","medium","significant","critical"]
+
+            current_dominant_incident = Counter(data[-lookback:][:-prior]).most_common(1)[0][0] #from LAST 23 elements fetch FIRST 15 elements
+            potential_dominant_incident = Counter(data[-post:]).most_common(1)[0][0] #fetch LAST 8 elements
+            current_dominant_incident_index = levels_list.index(current_dominant_incident)
+            potential_dominant_incident_index = levels_list.index(potential_dominant_incident)
+
+            if current_dominant_incident_index <= potential_dominant_incident_index:
+                return True
+            else:
                 return False
 
         alerts = []
@@ -289,7 +293,7 @@ class FireSmokeUseCase(BaseProcessor):
                         "alert_id": "alert_"+category+'_'+frame_key,
                         "incident_category": self.CASE_TYPE,
                         "threshold_level": threshold,
-                        "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
+                        "ascending": get_trend(self._ascending_alert_list, lookback=23, prior=14),
                         "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
                                      getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])
                                     }                    
@@ -303,7 +307,7 @@ class FireSmokeUseCase(BaseProcessor):
                             "alert_id": "alert_"+category+'_'+frame_key,
                             "incident_category": self.CASE_TYPE,
                             "threshold_level": threshold,
-                            "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
+                            "ascending": get_trend(self._ascending_alert_list, lookback=23, prior=14),
                             "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
                                      getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])
                                     }       
@@ -323,6 +327,25 @@ class FireSmokeUseCase(BaseProcessor):
     ) -> Dict:
         """Generate structured events for fire and smoke detection output with frame-aware keys."""
 
+        def get_trend_incident(data, lookback=23, prior=14):
+            '''
+            Determine if the trend is ascending or descending based on actual value progression.
+            Now works with determining dominant levels.
+            '''
+            if len(data) < lookback:
+                return "",0,"",0
+
+            post=lookback-prior-1
+            levels_list = ["low","medium","significant","critical"]
+            current_dominant_incident = Counter(data[-lookback:][:-prior]).most_common(1)[0][0] #from LAST 23 elements fetch FIRST 15 elements
+            current_dominant_incident_index = levels_list.index(current_dominant_incident)
+
+            potential_dominant_incident = Counter(data[-post:]).most_common(1)[0][0] #fetch LAST 8 elements
+            potential_dominant_incident_index = levels_list.index(potential_dominant_incident)
+
+            return current_dominant_incident, current_dominant_incident_index, potential_dominant_incident, potential_dominant_incident_index
+
+
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
         incidents = []
        
@@ -334,7 +357,8 @@ class FireSmokeUseCase(BaseProcessor):
         total_smoke = by_category.get("smoke", 0)
         current_timestamp = self._get_current_timestamp_str(stream_info)
         camera_info = self.get_camera_info_from_stream(stream_info)
-        self._ascending_alert_list = self._ascending_alert_list[-900:] if len(self._ascending_alert_list) > 900 else self._ascending_alert_list
+        self._ascending_alert_list = self._ascending_alert_list[-5000:] if len(self._ascending_alert_list) > 5000 else self._ascending_alert_list
+        levels_list = ["low","medium","significant","critical"]
         print("-----------INCIDENTS-----------")
         print(total)
         print(summary.get("per_category_count", {}))
@@ -351,7 +375,10 @@ class FireSmokeUseCase(BaseProcessor):
                     if start_timestamp and self.current_incident_end_timestamp=='N/A':
                         self.current_incident_end_timestamp = 'Incident still active'
                     elif start_timestamp and self.current_incident_end_timestamp=='Incident still active':
-                        if len(self._ascending_alert_list) >= 15 and sum(self._ascending_alert_list[-15:]) / 15 < 1.5: 
+                        current_dominant_incident, current_dominant_incident_index, potential_dominant_incident, potential_dominant_incident_index = get_trend_incident(self._ascending_alert_list, lookback=23, prior=14) #from LAST 23 elements fetch FIRST 15 elements           
+                        
+                        if current_dominant_incident != potential_dominant_incident:
+                            
                             self.current_incident_end_timestamp = current_timestamp
                     elif self.current_incident_end_timestamp!='Incident still active' and self.current_incident_end_timestamp!='N/A':
                         self.current_incident_end_timestamp = 'N/A'
@@ -374,35 +401,35 @@ class FireSmokeUseCase(BaseProcessor):
                     intensity_pct = min(100.0, (total_area / threshold_area) * 100)
 
                     if config.alert_config and config.alert_config.count_thresholds:
-                            if intensity_pct >= 40:
+                            if intensity_pct >= 30:
                                 level = "critical"
-                                self._ascending_alert_list.append(3)
-                            elif intensity_pct >= 30:
+                                self._ascending_alert_list.append(level)
+                            elif intensity_pct >= 13:
                                 level = "significant"
-                                self._ascending_alert_list.append(2)
-                            elif intensity_pct >= 5:
+                                self._ascending_alert_list.append(level)
+                            elif intensity_pct >= 3:
                                 level = "medium"
-                                self._ascending_alert_list.append(1)
+                                self._ascending_alert_list.append(level)
                             else:
                                 level = "low"
-                                self._ascending_alert_list.append(0)
+                                self._ascending_alert_list.append(level)
                     else:
-                            if intensity_pct > 40:
+                            if intensity_pct > 29:
                                 level = "critical"
                                 intensity = 10.0
-                                self._ascending_alert_list.append(3)
-                            elif intensity_pct > 30:
+                                self._ascending_alert_list.append(level)
+                            elif intensity_pct > 12:
                                 level = "significant"
                                 intensity = 9.0
-                                self._ascending_alert_list.append(2)
-                            elif intensity_pct > 4:
+                                self._ascending_alert_list.append(level)
+                            elif intensity_pct > 2:
                                 level = "medium"
                                 intensity = 7.0
-                                self._ascending_alert_list.append(1)
+                                self._ascending_alert_list.append(level)
                             else:
                                 level = "low"
                                 intensity = min(10.0, intensity_pct / 3.0)
-                                self._ascending_alert_list.append(0)
+                                self._ascending_alert_list.append(level)
 
                     # Generate human text in new format
                     human_text_lines = [f"INCIDENTS DETECTED @ {current_timestamp}:"]
@@ -424,12 +451,12 @@ class FireSmokeUseCase(BaseProcessor):
                     event= self.create_incident(incident_id=self.CASE_TYPE+'_'+str(frame_number), incident_type=self.CASE_TYPE,
                             severity_level=level, human_text=human_text, camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
                             start_time=start_timestamp, end_time=self.current_incident_end_timestamp,
-                            level_settings= {"low": 1, "medium": 5, "significant":40, "critical": 60})
+                            level_settings= {"low": 3, "medium": 5, "significant":15, "critical": 30})
                     event['duration'] = self.get_duration_seconds(start_timestamp, self.current_incident_end_timestamp)
                     incidents.append(event)
 
         else:
-            self._ascending_alert_list.append(0)
+            #self._ascending_alert_list.append(level)
             incidents.append({})
         return incidents
 
@@ -597,7 +624,7 @@ class FireSmokeUseCase(BaseProcessor):
             ]
             counts = {}
             for det in detections:
-                cat = det.get('category', 'unknown')
+                cat = det.get('category', 'unknown').lower()
                 counts[cat] = counts.get(cat, 0) + 1
             
 
@@ -672,7 +699,7 @@ class FireSmokeUseCase(BaseProcessor):
                     if width > 0 and height > 0:
                         total_area += width * height
 
-        threshold_area = 10000.0  # Same threshold as insights/alerts
+        threshold_area = 250200.0  # Same threshold as insights/alerts
 
         intensity_pct = min(100.0, (total_area / threshold_area) * 100)
         metrics["intensity_percentage"] = intensity_pct
@@ -725,7 +752,7 @@ class FireSmokeUseCase(BaseProcessor):
                 "fire_smoke_categories": {
                     "type": "array",
                     "items": {"type": "string"},
-                    "default": ["Fire", "Smoke"],
+                    "default": ["fire", "smoke"],
                     "description": "Category names that represent fire and smoke",
                 },
                 "index_to_category": {
@@ -753,8 +780,8 @@ class FireSmokeUseCase(BaseProcessor):
         defaults = {
             "category": self.category,
             "usecase": self.name,
-            "confidence_threshold": 0.5,
-            "fire_smoke_categories": ["Fire", "Smoke"],
+            "confidence_threshold": 0.3,
+            "fire_smoke_categories": ["fire", "smoke"],
         }
         defaults.update(overrides)
         return FireSmokeConfig(**defaults)
